@@ -16,7 +16,7 @@ from .prediction import Prediction
 from .sentiment_analysis import SentimentAnalysis
 from .toucan import Toucan
 
-__version__ = "0.9.3"
+__version__ = "0.9.5"
 
 darkknight = DarkKnight
 ftp = Ftp
@@ -25,7 +25,7 @@ ftps_toucan = Ftps_toucan
 git = Git
 geoLocator = GeoLocator
 google_spreadsheet = GoogleSpreadsheet
-healthCheck = HealthCheck
+health_check = HealthCheck
 email = Email
 mongo = Mongo
 pdf = Pdf
